# psgnuitka - a GUI tool to build app with nuitka

---

本工具还处于早期开发阶段，部分功能和想法还在技术实现和优化中：

目标想要实现的功能有：

- 自动检索可用的Python解释器位置
- 自动创建venv环境用于干净环境的打包构建
- 可内置相关的Nuitka所需的工具链软件方便统一构建环境
- 提供对多版本Nuitka的支持
- 支持多国语言
- 按照使用者的级别提供不同级别的构建界面
- 支持Windows、Linux、Mac OS

---



## 概述

Nuitka是一个Python的编译器，可以无缝替换或者扩展Python解释器

Nuitka会将Python模块转换为C语言程序，从而利用C语言的编译工具链构建可执行文件

Nuitka通常能够让你的Python程序获得更高的运行性能，不过因为需要利用传统的C语言编译，所以在第一次执行之前需要较长时间的构

Nuitka需要使用命令行的方式进行调用，通常构建一般的Python脚本需要较长的命令

psgnuitka工具就是用来解决Nuitka命令太长且复杂的一个工具，通过图形化界面引导，只需要轻松几步，就能快速生成需要的命令，并可以支持一键调用

你可以使用pip命令很方便的安装此工具，或者可以通过 `github`仓库获取二进制可发行版本

目前此工具还处于早期开发阶段，存在部分设计不合理和功能缺失

如有问题或者建议，可以通过issue或者邮件交流

---

本工具的开发离不开如下工具的帮助

Nuitka

PySimpleGUI

Python

Poetry

---
